package com.huiju.estateagents.mapper;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.huiju.estateagents.entity.TaBuilding;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.huiju.estateagents.entity.TaPersonBuilding;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Update;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 项目表 Mapper 接口
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@Mapper
public interface TaBuildingMapper extends BaseMapper<TaBuilding> {
    /**
     * 楼盘列表
     * @param page
     * @return
     */
    List<TaBuilding> buildingList(IPage<TaBuilding> page, @Param("Name") String name, @Param("Code")String code,@Param("startDate")LocalDateTime startDate, @Param("buildingStatus")String buildingStatus, @Param("marketStatus")String marketStatus, @Param("cityId")Integer cityId, @Param("isMain")Integer isMain, @Param("orgId") Integer orgId,@Param("personBuildingList") List<TaPersonBuilding> personBuildingList);

    /**
     * 楼盘列表
     * @param page
     * @param
     * @return
     */
    List<TaBuilding> buildingListSelect(IPage<TaBuilding> page, @Param("Name") String name, @Param("Code") String code, @Param("startDate") LocalDateTime startDate, @Param("buildingStatus") String buildingStatus, @Param("marketStatus") String marketStatus, @Param("cityId") Integer cityId, @Param("isMain") Integer isMain, @Param("orgId") Integer orgId, @Param("personBuildingList") List<TaPersonBuilding> personBuildingList);


    @Update("UPDATE ta_building  SET ${field} = IFNULL(${field}, 0) + #{increment}  WHERE building_id = #{buildingId}")
    void setFieldNum(@Param("buildingId") String buildingId, @Param("field") String field, @Param("increment") int increment);

    List<TaBuilding> buildingAll(@Param("orgId") Integer orgId);

    List<TaBuilding> getBuildingListById(@Param("orgId") Integer orgId,@Param("cityId") Integer cityId);
    /**
     * 查询当前楼盘
     * @param buildingId
     * @return
     */
    TaBuilding selectBuilding(@Param("buildingId") String buildingId);

    /**
     * 转化率 项目收藏 / 项目分享
     * @return
     */
    Map<String, Object> selectBuildingStatistical(@Param("orgId")Integer orgId, @Param("saveOrShare") String saveOrShare);

    /**
     * 查询楼盘
     * @param page
     * @param name
     * @param cityId
     * @param targets
     * @param houseTypeList
     * @param buildingTypeList
     * @param priceList
     * @param areaList
     * @return
     */
    IPage<TaBuilding> selectBuildingPage(IPage<TaBuilding> page,
                                         @Param("name") String name,
                                         @Param("cityId") Integer cityId,
                                         @Param("targets") List<String> targets,
                                         @Param("houseTypeList") String[] houseTypeList,
                                         @Param("buildingTypeList") String[] buildingTypeList,
                                         @Param("priceList") List<String[]> priceList,
                                         @Param("areaList") List<String[]> areaList,
                                         @Param("orgId")Integer orgId);

    /**
     * 根据项目类型Id 查询
     * @param buildingTypeId
     * @return
     */
    List<TaBuilding> selectBuildingByBuildingTypeId(Integer buildingTypeId);

    /**
     * 根据权重统计该权重是否存在
     * @return
     */
    int countNumByHeavy(@Param("heavy") Integer heavy, @Param("dynamicId") String dynamicId);

    List<TaBuilding> selectMainBuildings(@Param("cityId") String cityId, @Param("orgId") Integer orgId);
}
