package com.huiju.estateagents.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaPersonVisitRecord;
import com.huiju.estateagents.entity.TdWxDict;
import com.huiju.estateagents.exception.EstaException;
import com.huiju.estateagents.mapper.*;
import com.huiju.estateagents.po.PersonPO;
import com.huiju.estateagents.service.IStatisticalService;
import com.huiju.estateagents.statistic.entity.TsPersonFromStatistic;
import com.huiju.estateagents.statistic.mapper.TsPersonFromStatisticMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * 数据统计
 */
@Service
@Slf4j
public class StatisticalServiceImpl implements IStatisticalService {

    @Autowired
    private TaPersonMapper taPersonMapper;

    @Autowired
    private TaBuildingMapper taBuildingMapper;


    @Autowired
    private TaPersonVisitRecordMapper taPersonVisitRecordMapper;

    @Autowired
    private TaBuildingDynamicMapper taBuildingDynamicMapper;

    @Autowired
    private TaNewsMapper taNewsMapper;

    @Autowired
    private TaPersonIntentionRecordMapper taPersonIntentionRecordMapper;

    @Autowired
    private TsPersonFromStatisticMapper tsPersonFromStatisticMapper;

    @Autowired
    private TdWxDictMapper tdWxDictMapper;


    @Override
    public ResponseBean indexStatistical(Integer orgId) {

        ResponseBean responseBean = new ResponseBean();
        Map<String,Object> map = new HashMap<>();

        // 总用户数
        Integer selectUserCount = taPersonMapper.selectUserCount(orgId);

        // 注册数
        Integer selectRegisteredCount = taPersonMapper.selectRegisteredCount(orgId);

        // 最近七天
        Integer selectRecentlyCount = taPersonMapper.selectRecentlyCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, null, null);

        // -------  用户来源 end ------------

        map.put("selectUserCount", selectUserCount);
        map.put("selectRegisteredCount", selectRegisteredCount);
        map.put("selectRecentlyCount", selectRecentlyCount);

        responseBean.addSuccess(map);

        return responseBean;
    }

    @Override
    public ResponseBean selectActiveUserCount(Integer orgId, String dateType, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();

        String type = null;
        if (CommConstant.DAY.equals(dateType)) {
            type = CommConstant.DAY;
        } else if (CommConstant.WEEK.equals(dateType)) {
            type = CommConstant.WEEK;
        } else if (CommConstant.MONTH.equals(dateType)) {
            type = CommConstant.MONTH;
        } else {
            responseBean.addError("无此查询类型！");
        }

        // 用户活跃数
        List<Map<String, Object>> selectActiveUserCount = taPersonMapper.selectActiveUserCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, type, null, null);
        Map<String, Object> map = new HashMap<>();
        map.put("selectActiveUserCount", selectActiveUserCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectNewsUserCount(Integer orgId, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();

        // 新增用户数
        List<Map<String, Object>> selectNewsUserCount = taPersonMapper.selectNewsUserCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate);

        Map<String, Object> map = new HashMap<>();
        map.put("selectNewsUserCount", selectNewsUserCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectUserBehavior(Integer pageNum,
                                           Integer pageSize,
                                           Integer orgId,
                                           LocalDate startDate,
                                           LocalDate endDate,
                                           String buildingId,
                                           String eventType,
                                           String event,
                                           String activity) {
        ResponseBean responseBean = new ResponseBean();

        // 用户行为
        List<PersonPO> selectUserBehavior = taPersonMapper.selectUserBehavior(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate, buildingId, eventType, event, activity);

        IPage<TaPersonVisitRecord> page = new Page<>(pageNum, pageSize);
        IPage<TaPersonVisitRecord> visitRecordIPage = taPersonVisitRecordMapper.selectAll(page, startDate, endDate, buildingId, eventType, event, activity, orgId);

        Map<String, Object> map = new HashMap<>();
        map.put("selectUserBehavior", selectUserBehavior);
        map.put("data", visitRecordIPage);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectEventAll(Integer orgId, String event, String personId) {
        ResponseBean responseBean = new ResponseBean();

        List<TaPersonVisitRecord> taPersonVisitRecords = taPersonVisitRecordMapper.selectEventAll(event, personId, orgId);
        responseBean.addSuccess(taPersonVisitRecords);
        return responseBean;
    }

    @Override
    public ResponseBean selectConversion(Integer orgId, String conversion) {
        ResponseBean responseBean = new ResponseBean();
        Map<String, Object> result = new HashMap<>();

        switch (conversion) {
            case CommConstant.BUILDING_SAVE:
                Map<String, Object> selectBuildingStatisticalSave = taBuildingMapper.selectBuildingStatistical(orgId, "save");
                result.put("data_count", selectBuildingStatisticalSave);
                break;
            case CommConstant.BUILDING_SHARE:
                Map<String, Object> selectBuildingStatisticalShare = taBuildingMapper.selectBuildingStatistical(orgId,"share");
                result.put("data_count", selectBuildingStatisticalShare);
                break;
            case CommConstant.ACTIVITY_SAVE:
                Map<String, Object> selectBuildingDynamicStatisticalSave = taBuildingDynamicMapper.selectBuildingDynamicStatistical(orgId, "save");
                result.put("data_count", selectBuildingDynamicStatisticalSave);
                break;
            case CommConstant.ACTIVITY_SHARE:
                Map<String, Object> selectBuildingDynamicStatisticalShare = taBuildingDynamicMapper.selectBuildingDynamicStatistical(orgId, "share");
                result.put("data_count", selectBuildingDynamicStatisticalShare);
                break;
            case CommConstant.NEWS_SAVE:
                Map<String, Object> selectNewsStatisticalSave = taNewsMapper.selectNewsStatistical(orgId, "save");
                result.put("data_count", selectNewsStatisticalSave);
                break;

            case CommConstant.NEWS_SHARE:
                Map<String, Object> selectNewsStatisticalShare = taNewsMapper.selectNewsStatistical(orgId, "share");
                result.put("data_count", selectNewsStatisticalShare);
                break;

            case CommConstant.ACTIVITY_SIGN:
                Map<String, Object> selectBuildingDynamicEnlistStatistical = taBuildingDynamicMapper.selectBuildingDynamicEnlistStatistical(orgId);
                result.put("data_count", selectBuildingDynamicEnlistStatistical);
                break;

            case CommConstant.AUTHORIZATION_PHONE:
                // 总用户数
                Integer selectUserCount = taPersonMapper.selectUserCount(orgId);

                // 注册数
                Integer selectRegisteredCount = taPersonMapper.selectRegisteredCount(orgId);
                Map<String, Object> userMap = new HashMap<>();
                userMap.put("pvNum", selectUserCount);
                userMap.put("registeredCount", selectRegisteredCount);
                result.put("data_count", userMap);
                break;
        }

        responseBean.addSuccess(result);
        return responseBean;
    }


    @Override
    public ResponseBean selectUserResource(Integer orgId, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();
        // 用户来源 柱状
        List<Map<String, Object>> mapList = taPersonMapper.selectUserSourceColumnar(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate);

        // 用户来源饼状
        // 来源置业顾问, 来源客户，其他
        Integer total = taPersonMapper.selectFromNum(orgId, null) ;
        Integer person_realty_consultant = taPersonMapper.selectFromNum(orgId, CommConstant.PERSON_REALTY_CONSULTANT);
        Integer person_estate_agent = taPersonMapper.selectFromNum(orgId, CommConstant.PERSON_ESTATE_CUSTOMER);
        Integer person_null = total - person_realty_consultant - person_estate_agent;
        Map<String, Object> map = new HashMap<>();
        map.put("person_realty_consultant", person_realty_consultant);
        map.put("person_estate_agent", person_estate_agent);
        map.put("person_null", person_null);

        // 用户来源 数据列表
        List<Map<String, Object>> selectUserSourceData = taPersonMapper.selectUserSourceData(orgId, CommConstant.PERSON_ESTATE_AGENT, startDate, endDate);

        Map<String, Object> result = new HashMap<>();
        result.put("columnar", mapList);
        result.put("pie", map);
        result.put("data", selectUserSourceData);

        responseBean.addSuccess(result);
        return responseBean;
    }


    @Override
    public ResponseBean selectUserCount(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();
        // 总用户数
        Integer selectUserCount = taPersonMapper.selectUserCount(orgId);
        Map<String, Object> map = new HashMap<>();
        map.put("selectUserCount", selectUserCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectRegisteredCount(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();
        // 注册数
        Integer selectRegisteredCount = taPersonMapper.selectRegisteredCount(orgId);
        Map<String, Object> map = new HashMap<>();
        map.put("selectRegisteredCount", selectRegisteredCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectRecentlyCount(Integer orgId, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();
        // 最近七天
        Integer selectRecentlyCount = taPersonMapper.selectRecentlyCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate);
        Map<String, Object> map = new HashMap<>();
        map.put("selectRecentlyCount", selectRecentlyCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectSexUser(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();

        // 性别比例
        // 1 男 2 女
        Integer selectSexMale = taPersonMapper.selectSexUser(orgId, CommConstant.SEX_MALE);
        Integer selectSexFemale = taPersonMapper.selectSexUser(orgId, CommConstant.SEX_FEMALE);
        Map<String, Object> selectSexMaleMap = new HashMap<>();
        selectSexMaleMap.put("name", "男");
        selectSexMaleMap.put("value", selectSexMale);
        Map<String, Object> selectSexFemaleMap = new HashMap<>();
        selectSexFemaleMap.put("name", "女");
        selectSexFemaleMap.put("value", selectSexFemale);
        List<Map<String, Object>> selectSexUser = new ArrayList<>();
        selectSexUser.add(selectSexMaleMap);
        selectSexUser.add(selectSexFemaleMap);

        Map<String, Object> map = new HashMap<>();
        map.put("selectSexUser", selectSexUser);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectCityUser(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();

        // 城市比例
        List<Map<String, Object>> selectCityUser = taPersonMapper.selectCityUser(orgId);
        Map<String, Object> map = new HashMap<>();
        map.put("selectCityUser", selectCityUser);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectIntentionUser(Integer pageNum, Integer pageSize, Integer orgId, String buildingId) {
        ResponseBean responseBean = new ResponseBean();

        IPage<Map<String,Object>> pg = new Page<>(pageNum, pageSize);
        IPage<Map<String, Object>> page = taPersonIntentionRecordMapper.selectIntentionUser(pg, orgId, buildingId);

        responseBean.addSuccess(page);
        return responseBean;
    }

    /**
     * 用户来源数据 首页
     *
     * @param orgId
     * @param startDate
     * @param endDate
     * @return
     */
    @Override
    public ResponseBean selectPersonFrom(Integer orgId, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();
        List<TsPersonFromStatistic> list = tsPersonFromStatisticMapper.selectPersonFrom(orgId,startDate,endDate);
        QueryWrapper<TdWxDict> tdWxDictQueryWrapper = new QueryWrapper<>();
        tdWxDictQueryWrapper.groupBy("scene_type");
        List<TdWxDict> tdWxDicts = tdWxDictMapper.selectList(tdWxDictQueryWrapper);
        tdWxDicts.forEach(e -> {
            int fromSum = list.stream().filter(l -> e.getSceneType().equals(l.getSceneType())).mapToInt(TsPersonFromStatistic::getFromNum).sum();
            int registerSum = list.stream().filter(l -> e.getSceneType().equals(l.getSceneType())).mapToInt(TsPersonFromStatistic::getRegisteredNum).sum();
            e.setFromData(fromSum);
            e.setRegisterSum(registerSum);
        });
        Map<String,Object> map = new HashMap<>();
        map.put("tdWxDicts",tdWxDicts);
        List<TsPersonFromStatistic> tableList = tsPersonFromStatisticMapper.selectPersonFromGroupByData(orgId,startDate,endDate);
        map.put("list",tableList);
        responseBean.addSuccess(map);
        return responseBean;
    }

    /**
     * 用户来源数据统计折线图
     *
     * @param orgId
     * @param startDate
     * @param endDate
     * @return
     */
    @Override
    public ResponseBean selectPersonFromGroupByDay(Integer orgId, LocalDate startDate, LocalDate endDate) {
        List<TsPersonFromStatistic> dayList = getDayList(startDate, endDate);
        List<TsPersonFromStatistic> list = tsPersonFromStatisticMapper.selectPersonFromGroupByDay(orgId,startDate,endDate);
        dayList.forEach(e -> {
            list.forEach(l -> {
                if (e.getCreateTime().equals(l.getCreateTime())){
                    e.setFromNum(l.getFromNum());
                    e.setRegisteredNum(l.getRegisteredNum());
                }
            });
        });
        return ResponseBean.success(dayList);
    }

    /**
     * 返回时间区间格式
     * @param startDate
     * @param endDate
     * @return
     */
    private List<TsPersonFromStatistic> getDayList(LocalDate startDate, LocalDate endDate) {
        if (null == startDate || null == endDate){
            endDate = LocalDate.now();
            startDate = LocalDate.now().plusDays(-7);
        }

        //获取时间区间
        List<LocalDate> dates = Stream.iterate(startDate, date -> date.plusDays(1))
                .limit(ChronoUnit.DAYS.between(startDate, endDate))
                .collect(Collectors.toList());

        //格式化时间
        List<TsPersonFromStatistic> dataList = new ArrayList<>();
        DateTimeFormatter dtf3 = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        dates.forEach(e -> {
            TsPersonFromStatistic tsPersonFromStatistic = new TsPersonFromStatistic();
            tsPersonFromStatistic.setRegisteredNum(0);
            tsPersonFromStatistic.setFromNum(0);
            tsPersonFromStatistic.setCreateTime(dtf3.format(e));
            dataList.add(tsPersonFromStatistic);
        });
        return dataList;
    }
}
